/**** e[u쐬 ****/
USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_machine] (
	[machine_id] [int] IDENTITY (1, 1) NOT NULL
		CONSTRAINT [PK_bom_machine] PRIMARY KEY CLUSTERED,
	[site_id] [int] DEFAULT 0 NOT NULL,
	[machine_mod_date] [datetime] NOT NULL,
	[machine_status] [nchar] (1) NOT NULL,
	[machine_name] [nchar] (256) NOT NULL,
	[machine_unique_name] [nchar] (256) NOT NULL
		CONSTRAINT [IX_bom_machine] UNIQUE,
	[machine_alias] [nchar] (256) NOT NULL,
	[machine_system_name] [nchar] (80) DEFAULT N' ' NOT NULL,
	[machine_ibom_svr_id] [nchar] (10) DEFAULT N' ' NOT NULL,
	[admin_code] [nchar] (10) DEFAULT N' ' NOT NULL,
	[machine_spec_code] [nchar] (10) DEFAULT N' ' NOT NULL,
	[agreement_num] [nchar] (10) DEFAULT N' ' NOT NULL
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_instance] (
	[instance_setup_id] [int] IDENTITY (1, 1) NOT NULL
		CONSTRAINT [PK_bom_instance] PRIMARY KEY NONCLUSTERED,
	[machine_id] [int] NOT NULL,
	[instance_mod_date] [datetime] NOT NULL,
	[instance_num] [smallint] DEFAULT 0 NOT NULL,
	[instance_icon_num] [smallint] DEFAULT 0 NOT NULL,
	[instance_name] [nvarchar] (127) NOT NULL,
	[product_code] [nchar] (5) NOT NULL,
	[service_release_code] [nchar] (3) NOT NULL,
	[archive_onoff] [nchar] (1) NOT NULL
) ON [PRIMARY]
GO
CREATE CLUSTERED INDEX [CIX_bom_instance] ON [bom_instance] (
	[machine_id],
	[instance_name],
	[instance_mod_date]
) ON [PRIMARY]


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_appl] (
	[appl_setup_id] INT IDENTITY (1, 1) NOT NULL
		CONSTRAINT [PK_bom_appl] PRIMARY KEY NONCLUSTERED,
	[appl_mod_date] [datetime] NOT NULL,
	[appl_num] [smallint] NOT NULL,
	[appl_name] [nvarchar] (127) NOT NULL,
	[appl_watch_on] [bit] NOT NULL,
	[instance_setup_id] [int] NOT NULL,
	[appl_icon_num] [smallint] NOT NULL,
	[appl_delete] [bit] NOT NULL
) ON [PRIMARY]
GO
CREATE CLUSTERED INDEX [CIX_bom_appl] ON [bom_appl] (
	[instance_setup_id],
	[appl_num],
	[appl_mod_date]
) ON [PRIMARY]


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_watch] (
	[watch_setup_id] [int] IDENTITY (1, 1) NOT NULL
		CONSTRAINT [PK_bom_watch] PRIMARY KEY NONCLUSTERED,
	[appl_setup_id] [int] NOT NULL,
	[watch_mod_date] [datetime] NOT NULL,
	[watch_num] [smallint] NOT NULL,
	[watch_on] [bit] NOT NULL,
	[watch_name] [nvarchar] (127) NOT NULL,
	[watch_comment] [nvarchar] (4000) NOT NULL,
	[watch_ret_type] [tinyint] NULL,
	[watch_int_y] [ntext] NOT NULL,
	[watch_int_y_chktype] [tinyint] NOT NULL,
	[watch_int_r] [ntext] NOT NULL,
	[watch_int_r_chktype] [tinyint] NOT NULL,
	[watch_icon_num] [smallint] NOT NULL,
	[watch_kind] [nchar] (32) NOT NULL,
	[watch_eventlog_on] [bit] NULL,
	[watch_delete] [bit] NOT NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE CLUSTERED INDEX [CIX_bom_watch] ON [bom_watch] (
	[appl_setup_id],
	[watch_num],
	[watch_mod_date]
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_watch] (
	[watch_setup_id] [int] NOT NULL,
	[archive_watch_time] [datetime] NOT NULL,
	[instance_setup_id] [int] NOT NULL,
	[appl_num] [smallint] NOT NULL,
	[watch_num] [smallint] NOT NULL,
	[archive_watch_value] [nvarchar] (255) NOT NULL,
	[archive_watch_status] [tinyint] NOT NULL,
	[archive_watch_resultcode] [nvarchar] (20) NULL, 
	[archive_watch_time_end] [datetime] NOT NULL
) ON [PRIMARY]
GO
CREATE CLUSTERED INDEX [CIX_bom_archive_watch] ON [bom_archive_watch] (
    [instance_setup_id],
    [appl_num],
    [watch_num],
    [archive_watch_time]
) ON [PRIMARY]
GO
CREATE INDEX [CIX_bom_archive_watch_time] ON [bom_archive_watch] (
	[watch_setup_id],
	[archive_watch_time]
) ON [PRIMARY]
GO

USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_history] (
	[instance_setup_id] [int] NOT NULL,
	[archive_status_category_num] [int] NOT NULL,
	[setup_id] [int] NOT NULL,
	[archive_status_time] [datetime] NOT NULL,
	[archive_status_message] [nvarchar] (4000) NOT NULL,
	[archive_status_status] [nvarchar] (32) DEFAULT N' ' NOT NULL,
	[archive_status_applname] [nvarchar] (250) NOT NULL,
	[archive_status_watchname] [nvarchar] (250) NOT NULL,
	[archive_status_type_num] [int] NOT NULL
) ON [PRIMARY]
GO
CREATE CLUSTERED INDEX [CIX_bom_archive_history] ON [bom_archive_history] (
    [instance_setup_id],
    [archive_status_category_num],
    [setup_id],
    [archive_status_time]
) ON [PRIMARY]
GO

USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_ntevent] (
	[archive_ntevent_id] [decimal] IDENTITY NOT NULL
		CONSTRAINT [PK_bom_archive_ntevent] PRIMARY KEY NONCLUSTERED,
	[watch_setup_id]				[int] NOT NULL,
	[instance_setup_id]				[int] NOT NULL,
	[appl_num]						[smallint] NULL,
	[watch_num]						[smallint] NULL,
	[archive_ntevent_record_num]	[int] NOT NULL,
	[archive_ntevent_generate_time]	[datetime] NOT NULL,
	[archive_ntevent_written_time]	[datetime] NOT NULL,
	[archive_ntevent_event_id]		[int] NOT NULL,
	[archive_ntevent_event_type]	[smallint] NOT NULL,
	[archive_ntevent_category]		[nvarchar] (255) NOT NULL,
	[archive_ntevent_source]		[nvarchar] (127) NOT NULL,
	[archive_ntevent_comp]			[nchar] (80) NOT NULL,
	[archive_ntevent_message]		[nvarchar] (4000) NOT NULL,
	[archive_ntevent_watch_server]	[nchar] (80) NOT NULL,
	[archive_ntevent_user]			[nchar] (36) NOT NULL,
	[archive_ntevent_log_name]		[nvarchar] (127) NOT NULL,
	[archive_ntevent_event_data]	[image] NULL,
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE CLUSTERED INDEX [CIX_bom_archive_ntevent] ON [bom_archive_ntevent] (
	[instance_setup_id],
	[archive_ntevent_log_name],
	[archive_ntevent_generate_time]
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_watch_value_string] (
	[watch_kind] [nchar] (32) NOT NULL,
	[archive_watch_value] [varchar] (255) NOT NULL,
	[watch_value_string] [varchar] (255) NOT NULL,
	CONSTRAINT [PK_bom_watch_value_string] PRIMARY KEY NONCLUSTERED (watch_kind, archive_watch_value)
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_watch_status_string] (
	[archive_watch_status_num] [tinyint] NOT NULL
		CONSTRAINT [PK_bom_archive_watch_status_string] PRIMARY KEY NONCLUSTERED,
	[archive_watch_status_string] [char] (8) NOT NULL,
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_ntevent_event_type_string] (
	[ntevent_event_type_num] [smallint] NOT NULL
		CONSTRAINT [PK_bom_ntevent_event_type_string] PRIMARY KEY NONCLUSTERED,
	[ntevent_event_type_string] [char] (16) NOT NULL
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_status_type] (
	[archive_status_type_num] [int] NOT NULL
		CONSTRAINT [PK_bom_archive_status_type] PRIMARY KEY NONCLUSTERED,
	[archive_status_type_string] [nvarchar] (50) NOT NULL
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_status_category] (
	[archive_status_category_num] [int] NOT NULL
		CONSTRAINT [PK_bom_archive_status_category] PRIMARY KEY NONCLUSTERED,
	[archive_status_category_string] [nvarchar] (50) NOT NULL
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_product_info] (
	[product_code] [char] (5) NOT NULL,
	[service_release_code] [char] (3) NOT NULL,
	[product_name] [nvarchar] (32) NOT NULL,
	[service_release_name] [nvarchar] (32) NOT NULL,
	[product_type] [nvarchar] (32) NOT NULL,
	CONSTRAINT [PK_bom_product_info] PRIMARY KEY NONCLUSTERED (product_code, service_release_code)
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_sysinfo_id](
	[sysinfo_id]	[int] IDENTITY(1,1) NOT NULL,
	[name_space]	[nchar](64)	COLLATE Japanese_CI_AS NULL,
	[class_name]	[nchar](64)	COLLATE Japanese_CI_AS NULL,
	[property_name] [nchar](64) COLLATE Japanese_CI_AS NULL,
	CONSTRAINT [PK_bom_archive_sysinfo_id] 
		PRIMARY KEY CLUSTERED (
			[sysinfo_id] ASC
		) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE INDEX [IX_bom_archive_sysinfo_id] 
	ON [dbo].[bom_archive_sysinfo_id](
	[name_space]	ASC,
	[class_name]	ASC,
	[property_name] ASC
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_sysinfo](
	[instance_setup_id] [int]	NOT NULL,
	[archive_time] [datetime]	NOT NULL,
	[sysinfo_id] [int]			NOT NULL,
	[set_num] [int]				NOT NULL,
	[value] [nvarchar](4000)	COLLATE Japanese_CI_AS NULL,
	CONSTRAINT [PK_bom_archive_sysinfo]
		PRIMARY KEY CLUSTERED(
			[instance_setup_id]	ASC,
			[archive_time]		ASC,
			[sysinfo_id]		ASC,
			[set_num]			ASC
		) ON [PRIMARY]
) ON [PRIMARY]
GO
ALTER TABLE [dbo].[bom_archive_sysinfo] 
	WITH CHECK ADD CONSTRAINT [FK_bom_archive_sysinfo_to_id] 
		FOREIGN KEY([sysinfo_id])
		REFERENCES [dbo].[bom_archive_sysinfo_id] ([sysinfo_id])
GO

CREATE NONCLUSTERED INDEX [IX_bom_archive_sysinfo_archive_time]
	ON [dbo].[bom_archive_sysinfo] ([archive_time])
	INCLUDE ([instance_setup_id])
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_watch_condition](
	[watch_setup_id]	[int] NOT NULL,
	[watch_object_name]	[nvarchar](512) COLLATE Japanese_CI_AS NULL,
	[watch_value_name]	[nvarchar](512) COLLATE Japanese_CI_AS NULL,
	[watch_option]		[nvarchar](512) COLLATE Japanese_CI_AS NULL,
	[watch_scale]		[decimal](20, 0) NULL,
	[watch_unit_symol]	[nvarchar](512) COLLATE Japanese_CI_AS NULL,
	CONSTRAINT [PK_bom_watch_condition] 
		PRIMARY KEY CLUSTERED (
			[watch_setup_id] ASC
		)ON [PRIMARY]
) ON [PRIMARY]
GO
ALTER TABLE [dbo].[bom_watch_condition] 
	WITH CHECK ADD CONSTRAINT [FK_bom_watch_condition_bom_watch] 
		FOREIGN KEY([watch_setup_id])
		REFERENCES [dbo].[bom_watch] ([watch_setup_id])
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_performance](
	[instance_setup_id]	[int]										NOT NULL,
	[target]			[nchar](64)			COLLATE Japanese_CI_AS	NOT NULL,
	[counter_id]		[int]										NOT NULL,
	[instance]			[nchar](64)			COLLATE Japanese_CI_AS	NOT NULL,
	[archive_time]		[datetime]									NOT NULL,
	[value]				[decimal](23,3)								NULL,
	[value_string]		[nvarchar](512)		COLLATE Japanese_CI_AS	NULL,
	CONSTRAINT [PK_bom_archive_performance]
		PRIMARY KEY CLUSTERED(
			[instance_setup_id]	ASC,
			[target]			ASC,
			[counter_id]		ASC,
			[instance]			ASC,
			[archive_time]		ASC
		) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE INDEX [IX_bom_archive_performance_archive_time] 
	ON [dbo].[bom_archive_performance] 
(
	[instance_setup_id] ASC,
	[archive_time] ASC,
	[counter_id] ASC
) ON [PRIMARY]
GO
CREATE INDEX [IX_bom_archive_performance_counter_id] 
	ON [dbo].[bom_archive_performance] 
(
	[instance_setup_id] ASC,
	[counter_id] ASC,
	[instance] ASC,
	[archive_time] ASC
) ON [PRIMARY]
GO
CREATE INDEX [IX_bom_archive_performance_target] 
	ON [dbo].[bom_archive_performance] 
(
	[instance_setup_id] ASC,
	[target] ASC,
	[counter_id] ASC,
	[archive_time] ASC
) ON [PRIMARY]
GO


USE [bom6_archive]
GO
CREATE TABLE [dbo].[bom_archive_performance_counterid](
	[instance_setup_id]	[int]										NOT NULL,
	[counter_id]		[int]										NOT NULL,
	[archive_time]		[datetime]									NOT NULL,
	[counter_name]		[nvarchar](64)		COLLATE Japanese_CI_AS	NULL,
	[group_string]		[nvarchar](64)		COLLATE Japanese_CI_AS	NULL,
	[unit_string]		[nvarchar](64)		COLLATE Japanese_CI_AS	NULL,
	[summary]			[nvarchar](512)		COLLATE Japanese_CI_AS	NULL,
	CONSTRAINT [PK_bom_archive_performance_counterid]
		PRIMARY KEY CLUSTERED(
			[instance_setup_id]	ASC,
			[counter_id]		ASC
		) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE INDEX [IX_bom_archive_performance_counterid_counter_name]
	ON [dbo].[bom_archive_performance_counterid](
	[instance_setup_id]	ASC,
	[group_string]		ASC,
	[counter_name]		ASC
) ON [PRIMARY]
GO
CREATE INDEX [IX_bom_archive_performance_counterid_unit_string]
	ON [dbo].[bom_archive_performance_counterid](
	[instance_setup_id]	ASC,
	[unit_string]		ASC
) ON [PRIMARY]
GO




INSERT INTO bom_archive_watch_status_string VALUES (0, N'')
INSERT INTO bom_archive_watch_status_string VALUES (1, N'')
INSERT INTO bom_archive_watch_status_string VALUES (2, N'댯')
INSERT INTO bom_archive_watch_status_string VALUES (4, N's')

DECLARE @kind NCHAR(32)
SET @kind = 'Service'
INSERT INTO bom_watch_value_string VALUES (@kind, 5, N'ĊJ')
INSERT INTO bom_watch_value_string VALUES (@kind, 6, N'ꎞ~')
INSERT INTO bom_watch_value_string VALUES (@kind, 7, N'ꎞ~')
INSERT INTO bom_watch_value_string VALUES (@kind, 4, N'Jn')
INSERT INTO bom_watch_value_string VALUES (@kind, 2, N'Jn')
INSERT INTO bom_watch_value_string VALUES (@kind, 3, N'~')
INSERT INTO bom_watch_value_string VALUES (@kind, 1, N'~')
/**http://msdn2.microsoft.com/en-us/library/ms685992.aspx Ql**/

SET @kind = 'Port'
INSERT INTO bom_watch_value_string VALUES (@kind, 4, N'J')
INSERT INTO bom_watch_value_string VALUES (@kind, 1, N'')

SET @kind = 'LinuxService'
INSERT INTO bom_watch_value_string VALUES (@kind, 4, N'J')
INSERT INTO bom_watch_value_string VALUES (@kind, 1, N'')

SET @kind = 'VMHWStatus';
INSERT INTO bom_watch_value_string VALUES (@kind, 0, N'')
INSERT INTO bom_watch_value_string VALUES (@kind, 1, N'')
INSERT INTO bom_watch_value_string VALUES (@kind, 2, N'댯')

SET @kind = 'VMStatus';
INSERT INTO bom_watch_value_string VALUES (@kind, 16, N'ڑ')
INSERT INTO bom_watch_value_string VALUES (@kind, 17, N'Ȃ')
INSERT INTO bom_watch_value_string VALUES (@kind, 18, N'ؒf')
INSERT INTO bom_watch_value_string VALUES (@kind, 32, N'ڑ')
INSERT INTO bom_watch_value_string VALUES (@kind, 33, N'ؒf')
INSERT INTO bom_watch_value_string VALUES (@kind, 34, N'Ǘ')
INSERT INTO bom_watch_value_string VALUES (@kind, 35, N'}')
INSERT INTO bom_watch_value_string VALUES (@kind, 36, N'')
INSERT INTO bom_watch_value_string VALUES (@kind, 272, N'p[I')
INSERT INTO bom_watch_value_string VALUES (@kind, 273, N'p[It')
INSERT INTO bom_watch_value_string VALUES (@kind, 274, N'X^oC')
INSERT INTO bom_watch_value_string VALUES (@kind, 275, N's')
INSERT INTO bom_watch_value_string VALUES (@kind, 288, N'p[It')
INSERT INTO bom_watch_value_string VALUES (@kind, 289, N'p[I')
INSERT INTO bom_watch_value_string VALUES (@kind, 290, N'TXyh')
INSERT INTO bom_watch_value_string VALUES (@kind, 528, N'm[}')
INSERT INTO bom_watch_value_string VALUES (@kind, 529, N'eiX')


INSERT INTO bom_ntevent_event_type_string VALUES (1, N'G[')
INSERT INTO bom_ntevent_event_type_string VALUES (2, N'x')
INSERT INTO bom_ntevent_event_type_string VALUES (4, N'')
INSERT INTO bom_ntevent_event_type_string VALUES (8, N'̊č')
INSERT INTO bom_ntevent_event_type_string VALUES (16, N's̊č')
INSERT INTO bom_ntevent_event_type_string VALUES (32, N'd')
INSERT INTO bom_ntevent_event_type_string VALUES (64, N'ڍ')

INSERT INTO bom_archive_status_type VALUES (0, N'')
INSERT INTO bom_archive_status_type VALUES (1, N'G[')
INSERT INTO bom_archive_status_type VALUES (2, N'x')
INSERT INTO bom_archive_status_type VALUES (4, N'')

INSERT INTO bom_archive_status_category VALUES (0, N'fobO')
INSERT INTO bom_archive_status_category VALUES (1, N'T[rX')
INSERT INTO bom_archive_status_category VALUES (2, N'Ď')
INSERT INTO bom_archive_status_category VALUES (3, N'ANV')
INSERT INTO bom_archive_status_category VALUES (4, N'ʒm')
INSERT INTO bom_archive_status_category VALUES (10, N'XPW[')
INSERT INTO bom_archive_status_category VALUES (11, N'Cxgnh[')
INSERT INTO bom_archive_status_category VALUES (20, N'vZXڍ׏')
INSERT INTO bom_archive_status_category VALUES (21, N'SQL ServerCX^X')

DECLARE @product_name NCHAR(32)
DECLARE @product_windows NCHAR(32)
DECLARE @product_linux NCHAR(32)
DECLARE @product_vmware NCHAR(32)
DECLARE @evaluation NCHAR(32)
SET @product_name = N'BOM 6'
SET @product_windows = N'ʏ퐻i'
SET @product_linux = N'LinuxIvV'
SET @product_vmware = N'VMwareIvV'
SET @evaluation = N']'

INSERT INTO [dbo].[bom_product_info] VALUES ('20100', '600', @product_name, N'', @product_windows)
INSERT INTO [dbo].[bom_product_info] VALUES ('20101', '600', @product_name, N'', @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('21100', '600', @product_name, N'', @product_linux)
INSERT INTO [dbo].[bom_product_info] VALUES ('21101', '600', @product_name, N'', RTRIM(@product_linux) + @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('22100', '600', @product_name, N'', @product_vmware)
INSERT INTO [dbo].[bom_product_info] VALUES ('22101', '600', @product_name, N'', RTRIM(@product_vmware) + @evaluation)

INSERT INTO [dbo].[bom_product_info] VALUES ('20100', '602', @product_name, N'', @product_windows)
INSERT INTO [dbo].[bom_product_info] VALUES ('20101', '602', @product_name, N'', @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('21100', '602', @product_name, N'', @product_linux)
INSERT INTO [dbo].[bom_product_info] VALUES ('21101', '602', @product_name, N'', RTRIM(@product_linux) + @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('22100', '602', @product_name, N'', @product_vmware)
INSERT INTO [dbo].[bom_product_info] VALUES ('22101', '602', @product_name, N'', RTRIM(@product_vmware) + @evaluation)

INSERT INTO [dbo].[bom_product_info] VALUES ('20100', '610', @product_name, N'SR1.0', @product_windows)
INSERT INTO [dbo].[bom_product_info] VALUES ('20101', '610', @product_name, N'SR1.0', @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('21100', '610', @product_name, N'SR1.0', @product_linux)
INSERT INTO [dbo].[bom_product_info] VALUES ('21101', '610', @product_name, N'SR1.0', RTRIM(@product_linux) + @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('22100', '610', @product_name, N'SR1.0', @product_vmware)
INSERT INTO [dbo].[bom_product_info] VALUES ('22101', '610', @product_name, N'SR1.0', RTRIM(@product_vmware) + @evaluation)

INSERT INTO [dbo].[bom_product_info] VALUES ('20100', '620', @product_name, N'SR2.0', @product_windows)
INSERT INTO [dbo].[bom_product_info] VALUES ('20101', '620', @product_name, N'SR2.0', @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('21100', '620', @product_name, N'SR2.0', @product_linux)
INSERT INTO [dbo].[bom_product_info] VALUES ('21101', '620', @product_name, N'SR2.0', RTRIM(@product_linux) + @evaluation)
INSERT INTO [dbo].[bom_product_info] VALUES ('22100', '620', @product_name, N'SR2.0', @product_vmware)
INSERT INTO [dbo].[bom_product_info] VALUES ('22101', '620', @product_name, N'SR2.0', RTRIM(@product_vmware) + @evaluation)
GO
